=== modified file 'bzrlib/bundle/serializer/v4.py'
--- bzrlib/bundle/serializer/v4.py	2007-06-29 18:20:57 +0000
+++ bzrlib/bundle/serializer/v4.py	2007-07-03 19:30:17 +0000
@@ -34,25 +34,45 @@
 
 class BundleWriter(object):
 
+    """Writer for bundle-format files.
+
+    This serves roughly the same purpose as ContainerReader, but acts as a
+    layer on top of it.
+
+    Provides ways of writing the spcific record types supported this bundle
+    format.
+    """
     def __init__(self, fileobj):
         self._container = pack.ContainerWriter(self._write_encoded)
         self._fileobj = fileobj
         self._compressor = bz2.BZ2Compressor()
 
+    def _write_encoded(self, bytes):
+        """Write bzip2-encoded bytes to the file"""
+        self._fileobj.write(self._compressor.compress(bytes))
+
     def begin(self):
+        """Start writing the bundle"""
         self._fileobj.write(serializer._get_bundle_header('4alpha'))
         self._fileobj.write('#\n')
         self._container.begin()
 
-    def _write_encoded(self, bytes):
-        self._fileobj.write(self._compressor.compress(bytes))
-
     def end(self):
+        """Finish writing the bundle"""
         self._container.end()
         self._fileobj.write(self._compressor.flush())
 
     def add_multiparent_record(self, mp_bytes, sha1, parents, repo_kind,
                                revision_id, file_id):
+        """Add a record for a multi-parent diff
+
+        :mp_bytes: A multi-parent diff, as a bytestring
+        :parents: a list of revision-ids of the parents
+        :repo_kind: The kind of object in the repository.  May be 'file' or
+            'inventory'
+        :revision_id: The revision id of the mpdiff being added.
+        :file_id: The file-id of the file, or None for inventories.
+        """
         metadata = {'parents': parents,
                     'storage_kind': 'mpdiff',
                     'sha1': sha1}
@@ -60,21 +80,40 @@
 
     def add_fulltext_record(self, bytes, parents, repo_kind, revision_id,
                             file_id):
+        """Add a record for a fulltext
+
+        :bytes: The fulltext, as a bytestring
+        :parents: a list of revision-ids of the parents
+        :repo_kind: The kind of object in the repository.  May be 'revision' or
+            'signature'
+        :revision_id: The revision id of the fulltext being added.
+        :file_id: must be None
+        """
+        metadata = {'parents': parents,
+                    'storage_kind': 'mpdiff',
+                    'sha1': sha1}
         self._add_record(bytes, {'parents': parents,
             'storage_kind': 'fulltext'}, repo_kind, revision_id, file_id)
 
     def add_info_record(self, **kwargs):
+        """Add an info record to the bundle
+
+        Any parameters may be supplied, except 'self' and 'storage_kind'.
+        Values must be lists, strings, integers, dicts, or a combination.
+        """
         kwargs['storage_kind'] = 'header'
         self._add_record(None, kwargs, 'info', None, None)
 
     @staticmethod
     def encode_name(content_kind, revision_id, file_id=None):
+        """Encode semantic ids as a container name"""
         assert content_kind in ('revision', 'file', 'inventory', 'signature',
                                 'info')
-        if content_kind in ('revision', 'inventory', 'signature', 'info'):
+
+        if content_kind == 'file':
+            assert file_id is not None
+        else:
             assert file_id is None
-        else:
-            assert file_id is not None
         if content_kind == 'info':
             assert revision_id is None
         else:
@@ -87,6 +126,12 @@
         return '/'.join(names)
 
     def _add_record(self, bytes, metadata, repo_kind, revision_id, file_id):
+        """Add a bundle record to the container.
+
+        Most bundle records are recorded as header/body pairs, with the
+        body being nameless.  Records with storage_kind 'header' have no
+        body.
+        """
         name = self.encode_name(repo_kind, revision_id, file_id)
         encoded_metadata = bencode.bencode(metadata)
         self._container.add_bytes_record(encoded_metadata, [name])
@@ -96,6 +141,12 @@
 
 class BundleReader(object):
 
+    """Reader for bundle-format files.
+
+    This serves roughly the same purpose as ContainerReader, but acts as a
+    layer on top of it, providing metadata, a semantic name, and a record
+    body
+    """
     def __init__(self, fileobj):
         line = fileobj.readline()
         if line != '\n':
@@ -106,12 +157,17 @@
 
     @staticmethod
     def iter_decode(fileobj):
+        """Iterate through decoded fragments of the file"""
         decompressor = bz2.BZ2Decompressor()
         for line in fileobj:
             yield decompressor.decompress(line)
 
     @staticmethod
     def decode_name(name):
+        """Decode a name from its container form into a semantic form
+
+        :retval: content_kind, revision_id, file_id
+        """
         names = name.split('/')
         content_kind = names[0]
         revision_id = None
@@ -123,6 +179,11 @@
         return content_kind, revision_id, file_id
 
     def iter_records(self):
+        """Iterate through bundle records
+
+        :return: a generator of (bytes, metadata, content_kind, revision_id,
+            file_id)
+        """
         iterator = self._container.iter_records()
         for (name,), meta_bytes in iterator:
             metadata = bencode.bdecode(meta_bytes(None))
@@ -136,26 +197,42 @@
 
 class BundleSerializerV4(serializer.BundleSerializer):
 
+    """Implement the high-level bundle interface"""
     def write(self, repository, revision_ids, forced_bases, fileobj):
+        """Write a bundle to a file-like object
+
+        For backwards-compatibility only
+        """
         write_op = BundleWriteOperation.from_old_args(repository, revision_ids,
                                                       forced_bases, fileobj)
         return write_op.do_write()
 
     def write_bundle(self, repository, target, base, fileobj):
+        """Write a bundle to a file object
+
+        :param repository: The repository to retrieve revision data from
+        :param target: The head revision to include ancestors of
+        :param base: The ancestor of the target to stop including acestors
+            at.
+        :param fileobj: The file-like object to write to
+        """
         write_op =  BundleWriteOperation(base, target, repository, fileobj)
         return write_op.do_write()
 
     def read(self, file):
+        """return a reader object for a given file"""
         bundle = BundleInfoV4(file, self)
         return bundle
 
     @staticmethod
     def get_source_serializer(info):
+        """Retrieve the serializer for a given info object"""
         return xml_serializer.format_registry.get(info['serializer'])
 
 
 class BundleWriteOperation(object):
 
+    """Perform the operation of writing revisions to a bundle"""
     @classmethod
     def from_old_args(cls, repository, revision_ids, forced_bases, fileobj):
         base, target = cls.get_base_target(revision_ids, forced_bases,
@@ -179,6 +256,7 @@
             self.revision_ids = revision_ids.difference(self.base_ancestry)
 
     def do_write(self):
+        """Write all data to the bundle"""
         self.bundle.begin()
         self.write_info()
         self.write_files()
@@ -187,6 +265,7 @@
         return self.revision_ids
 
     def write_info(self):
+        """Write format info"""
         serializer_format = self.repository.get_serializer_format()
         supports_rich_root = {True: 1, False: 0}[
             self.repository.supports_rich_root()]
@@ -194,11 +273,11 @@
                                     supports_rich_root=supports_rich_root)
 
     def iter_file_revisions(self):
-        """This is the correct approach, but not compatible.
+        """Iterate through all relevant revisions of all files.
 
-        It does not work with bzr.dev, because certain old revisions were not
-        converted correctly, and have the wrong "revision" marker in
-        inventories.
+        This is the correct implementation, but is not compatible with bzr.dev,
+        because certain old revisions were not converted correctly, and have
+        the wrong "revision" marker in inventories.
         """
         transaction = self.repository.get_transaction()
         altered = self.repository.fileids_altered_by_revision_ids(
@@ -208,7 +287,7 @@
             yield vf, file_id, file_revision_ids
 
     def iter_file_revisions_aggressive(self):
-        """Ensure that all required revisions are fetched.
+        """Iterate through all relevant revisions of all files.
 
         This uses the standard iter_file_revisions to determine what revisions
         are referred to by inventories, but then uses the versionedfile to
@@ -231,10 +310,12 @@
             yield vf, file_id, new_revision_ids
 
     def write_files(self):
+        """Write bundle records for all revisions of all files"""
         for vf, file_id, revision_ids in self.iter_file_revisions_aggressive():
             self.add_mp_records('file', file_id, vf, revision_ids)
 
     def write_revisions(self):
+        """Write bundle records for all revisions and signatures"""
         inv_vf = self.repository.get_inventory_weave()
         revision_order = list(multiparent.topo_iter(inv_vf, self.revision_ids))
         if self.target is not None and self.target in self.revision_ids:
@@ -268,6 +349,7 @@
         return base, target
 
     def add_mp_records(self, repo_kind, file_id, vf, revision_ids):
+        """Add multi-parent diff records to a bundle"""
         revision_ids = list(multiparent.topo_iter(vf, revision_ids))
         mpdiffs = vf.make_mpdiffs(revision_ids)
         sha1s = vf.get_sha1s(revision_ids)
@@ -280,6 +362,7 @@
 
 class BundleInfoV4(object):
 
+    """Provide (most of) the BundleInfo interface"""
     def __init__(self, fileobj, serializer):
         self._fileobj = fileobj
         self._serializer = serializer

